aboutsummaryrefslogtreecommitdiff
path: root/externals/grill/py/scripts/pak.py
diff options
context:
space:
mode:
authorThomas Grill <xovo@users.sourceforge.net>2005-01-19 04:58:36 +0000
committerThomas Grill <xovo@users.sourceforge.net>2005-01-19 04:58:36 +0000
commit6138980e885884ef96b726f695fb038e2b939935 (patch)
tree764c56a9a16e4175699ba9fd5cb45a9a3282fe46 /externals/grill/py/scripts/pak.py
parent86ecf983a799e73b54a13616e5fda6b268c20e5e (diff)
- a bit more functions for the symbol type
- exporting symbol functions corrected argument passing to class methods updated for OSX adjust pd and py files for correct argument passing svn path=/trunk/; revision=2523
Diffstat (limited to 'externals/grill/py/scripts/pak.py')
-rw-r--r--externals/grill/py/scripts/pak.py6
1 files changed, 3 insertions, 3 deletions
diff --git a/externals/grill/py/scripts/pak.py b/externals/grill/py/scripts/pak.py
index 17841630..6394570d 100644
--- a/externals/grill/py/scripts/pak.py
+++ b/externals/grill/py/scripts/pak.py
@@ -8,7 +8,7 @@ class pak(pyext._class):
# initialize list
self.lst = [0 for x in range(n)]
- def _anything_(self,n,args):
- # args should be type-checked!
- self.lst[n-1] = args
+ def _anything_(self,n,arg):
+ # arg should be type-checked!
+ self.lst[n-1] = arg
self._outlet(1,self.lst)